<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de http://trad.spip.net/tradlang_module/compresseur?lang_cible=ro
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// I
	'info_compresseur_titre' => 'Optimizări şi compresie',
	'info_question_activer_compactage_css' => 'Doriţi să activaţi compactarea foilor de stil (CSS) ?', # MODIF
	'info_question_activer_compactage_js' => 'Doriţi să activaţi compactarea scripturilor (javascript) ?', # MODIF

	// T
	'texte_compacter_avertissement' => 'Atenţie: nu activaţi aceste opţiuni în timpul dezvoltării site-ului dumneavoastră, pentru că elementele compactate îşi pierd lizibilitatea.',
	'texte_compacter_script_css' => 'SPIP poate compacta script-urile javascript şi foile de stil CSS pentru a le înregistra în fişiere statice; aceasta operaţiune accelerează afişarea site-ului.',
	'titre_compacter_script_css' => 'Compactarea script-urilor şi a CSS-urlor'
);

?>
